@@ -40,4 +40,9 @@ class ManagerTest(test.TestCase):
 
     def test_get_for_model(self):
         self.assertEquals(BAR_NUMBER*FOO_NUMBER, Bar.objects.get_for_model(Foo).count())
-        
+
+    def test_patched_filter(self):
+        self.assertEquals(BAR_NUMBER, Bar.objects.filter(content_object=self.foo).count())
+
+    def test_patched_exclude(self):
+        self.assertEquals(BAR_NUMBER* (FOO_NUMBER-1), Bar.objects.exclude(content_object=self.foo).count())
